@@ -139,7 +139,7 @@ loadDeviceCfg (PilotState *p)
 		  if (device->type == PILOT_DEVICE_SERIAL) {
 			  g_message ("Cradle Type -> Serial");
 		  } else if (device->type == PILOT_DEVICE_USB_VISOR) {
-			  g_message ("Cradle Type -> Handspring USB");
+			  g_message ("Cradle Type -> USB");
 		  } else if (device->type == PILOT_DEVICE_IRDA) {
 			  g_message ("Cradle Type -> IrDA");
 		  } else if (device->type == PILOT_DEVICE_NETWORK) {
@@ -353,6 +353,8 @@ load_conduit_list (GPilotPilot *pilot)
 		conduit_state->pilot = pilot;
 		conduit_state->management = gnome_pilot_conduit_management_new (conduit_state->name, GNOME_PILOT_CONDUIT_MGMT_NAME);
 		conduit_state->config = gnome_pilot_conduit_config_new (conduit_state->management, pilot->pilot_id);
+		gnome_pilot_conduit_config_load_config (conduit_state->config);
+
 		conduit_state->description = g_strdup ((gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "description", NULL));
 		conduit_state->icon = g_strdup ((gchar*)gnome_pilot_conduit_management_get_attribute (conduit_state->management, "icon", NULL));
 		if (conduit_state->icon == NULL || g_file_test (conduit_state->icon, G_FILE_TEST_ISFILE)==FALSE) {
@@ -371,15 +373,19 @@ load_conduit_list (GPilotPilot *pilot)
 		else 
 			conduit_state->default_sync_type = gnome_pilot_conduit_sync_type_str_to_int (buf);
 
-		conduit_state->enabled = gnome_pilot_conduit_config_is_enabled (conduit_state->config, &conduit_state->sync_type);
+		conduit_state->enabled = gnome_pilot_conduit_config_is_enabled (conduit_state->config, NULL);
+		conduit_state->sync_type = conduit_state->config->sync_type;
+		conduit_state->first_sync_type = conduit_state->config->first_sync_type;
+
 		conduit_state->orig_enabled = conduit_state->enabled;
 		if (conduit_state->enabled) 
 			conduit_state->orig_sync_type = conduit_state->sync_type;
 		else 
 			conduit_state->orig_sync_type = GnomePilotConduitSyncTypeNotSet;
+		conduit_state->orig_first_sync_type = conduit_state->first_sync_type;
 		conduit_states = g_list_append (conduit_states, conduit_state);
 		conduits = conduits->next;
-			
+
 		buf = (gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "valid-synctypes", NULL);
 		if (buf != NULL) {
 			gchar **sync_types = g_strsplit (buf, " ", 0);
